@@ -15,7 +15,7 @@
 static int ikey3k_open(ifd_reader_t * reader, const char *device_name)
 {
 	ifd_device_t *dev;
-        ifd_device_params_t params;
+	ifd_device_params_t params;
 
 	reader->name = "Rainbow iKey 3000";
 	reader->nslots = 1;
@@ -27,13 +27,13 @@ static int ikey3k_open(ifd_reader_t * reader, const char *device_name)
 		return -1;
 	}
 
-        params = dev->settings;
-        params.usb.interface = 0;
-        if (ifd_device_set_parameters(dev, &params) < 0) {
-                ct_error("ikey3k: setting parameters failed", device_name);
-                ifd_device_close(dev);
-                return -1;
-        }
+	params = dev->settings;
+	params.usb.interface = 0;
+	if (ifd_device_set_parameters(dev, &params) < 0) {
+		ct_error("ikey3k: setting parameters failed", device_name);
+		ifd_device_close(dev);
+		return -1;
+	}
 
 	reader->device = dev;
 
@@ -142,11 +142,11 @@ static int ikey3k_set_protocol(ifd_reader_t * reader, int nslot, int proto)
 static int ikey3k_send(ifd_reader_t * reader, unsigned int dad,
 		       const unsigned char *buffer, size_t len)
 {
-	int value, index;
+	int value, idx;
 	value = buffer[1] << 8 | buffer[0];
-	index = buffer[3] << 8 | buffer[2];
+	idx = buffer[3] << 8 | buffer[2];
 
-	return ifd_usb_control(reader->device, 0x41, 0x17, value, index,
+	return ifd_usb_control(reader->device, 0x41, 0x17, value, idx,
 			       (void *)&buffer[4], len - 4, -1);
 }
 
