@@ -128,6 +128,12 @@ void workaround_timeout(int sig)
 }
 #endif
 
+int ifd_sysdep_usb_capture_event(ifd_device_t * dev, ifd_usb_capture_t * cap,
+			   void *buffer, size_t len)
+{
+	return IFD_ERROR_NOT_SUPPORTED;
+}
+
 int ifd_sysdep_usb_capture(ifd_device_t * dev, ifd_usb_capture_t * cap,
 			   void *buffer, size_t len, long timeout)
 {
@@ -170,6 +176,14 @@ int ifd_sysdep_usb_end_capture(ifd_device_t * dev, ifd_usb_capture_t * cap)
 	return 0;
 }
 
+/*
+ * Event fd
+ */
+int ifd_sysdep_usb_get_eventfd(ifd_device_t * dev, short *events)
+{
+	return -1;
+}
+
 /*
  * USB control command
  */
