@@ -29,6 +29,8 @@ enum {
 	IFD_PROTOCOL_TLP,		/* older Gemplus protocol */
 	IFD_PROTOCOL_GBP,		/* Gemplus block protocol */
 	IFD_PROTOCOL_EUROCHIP,		/* Eurochip Countercard */
+	IFD_PROTOCOL_TCL,		/* ISO 14443-4 T=CL */
+	IFD_PROTOCOL_ESCAPE,		/* Virtual 'escape' protocol */
 	IFD_PROTOCOL_TRANSPARENT = 128
 };
 
@@ -175,6 +177,11 @@ extern int			ifd_protocol_write_memory(ifd_protocol_t *,
 					int, unsigned short,
 					const unsigned char *, size_t);
 extern void			ifd_protocol_free(ifd_protocol_t *);
+extern int			ifd_before_command(ifd_reader_t *);
+extern int			ifd_after_command(ifd_reader_t *);
+extern int			ifd_get_eventfd(ifd_reader_t *, short *);
+extern void			ifd_poll(ifd_reader_t *);
+extern int			id_event(ifd_reader_t *);
 
 /* Debugging macro */
 #ifdef __GNUC__
